//----------------------------------------------------------------------------------------------------------------------
// File:        lmquad.tpl
// Model:       Quadratic linear model, estimating sigma as a free parameter
// Parameters:  b0, b1, b2, sigma
// Fitted data: Y
// Likelihood:  Normal
// History:     17 Jan 2013  Arni Magnusson created
//----------------------------------------------------------------------------------------------------------------------

GLOBALS_SECTION
  #include "admodel.h"
  ofstream mcmc_report("mcmc.csv");
  const double pi = 3.141592654;

DATA_SECTION
  init_int n
  init_vector X(1,n)
  init_vector Y(1,n)
  number halfnlog2pi
  int mcmc_lines

PARAMETER_SECTION
  init_number b0
  init_number b1
  init_number b2
  init_number logsigma
  sdreport_number sigma
  sdreport_number xopt
  vector Yfit(1,n)
  matrix summary(1,n,1,3)  // | X | Y | Yfit |
  objective_function_value neglogL

PRELIMINARY_CALCS_SECTION
  halfnlog2pi = 0.5*n*log(2*pi);
  mcmc_lines = 0;

PROCEDURE_SECTION
  Yfit = b0 + b1*X + b2*square(X);
  sigma = mfexp(logsigma);
  xopt = -0.5 * b1/b2;
  neglogL = halfnlog2pi + n*logsigma + norm2(Y-Yfit)/(2*sigma*sigma);
  if(mceval_phase())
    write_mcmc();

REPORT_SECTION
  get_summary();
  report<<"# b0"     <<endl<<b0           <<endl
        <<"# b1"     <<endl<<b1           <<endl
        <<"# b2"     <<endl<<b2           <<endl
        <<"# RSS"    <<endl<<norm2(Y-Yfit)<<endl
        <<"# sigma"  <<endl<<sigma        <<endl
        <<"# xopt"   <<endl<<xopt         <<endl
        <<"# neglogL"<<endl<<neglogL<<endl<<endl;
  report<<"# Model summary"<<endl
        <<" X Y Yfit"<<endl
        <<summary<<endl;

FUNCTION get_summary
  summary.colfill(1,X);
  summary.colfill(2,Y);
  summary.colfill(3,Yfit);

FUNCTION write_mcmc
  if(mcmc_lines == 0)
    mcmc_report<<"neglogL,b0,b1,b2,sigma,xopt"<<endl;
  mcmc_report<<neglogL<<","<<b0<<","<<b1<<","<<b2<<","<<sigma<<","<<xopt<<endl;
  mcmc_lines++;
